@@ -11,7 +11,7 @@
 
 
 static NSInteger const kMaxLaunchTimeInSeconds = 15;
-static NSString * const kVersion = @"1.9.0";
+static NSString * const kVersion = @"1.9.1";
 static NSString * const kJsPrintSource = @"(function() { return document.getElementsByTagName('html')[0].outerHTML })();";
 
 
@@ -117,7 +117,7 @@ static NSString * const kJsPrintSource = @"(function() { return document.getElem
     }
 }
 
-- (void)listTabLinks:(Arguments *)args {
+- (void)listTabsLinks:(Arguments *)args {
     if (self->outputFormat == kOutputFormatJSON) {
         NSMutableArray *tabInfos = [[NSMutableArray alloc] init];
 
